@@ -12,7 +12,9 @@ class Document:
         self.document_id = json['documentId']
 
         #: Tipo do documento. Possivelmente nulo. Ver
-        #: :class:`DocumentType <DocumentType>`.
+        #: :class:`DocumentType <DocumentType>` ou
+        #: :class:`ExternalDocumentType <ExternalDocumentType>`, dependendo de
+        #: onde a instância foi encontrada.
         self.document_type = json.get('documentType')
 
         #: Identificador do grupo ao qual o documento pertence. Possivelmente
@@ -33,12 +35,18 @@ class Document:
         #: Recibo do documento. Possivelmente nulo.
         self.receipt = json.get('receipt')
 
+        #: Estado de autorização do documento. Possivelmente nulo. Ver
+        #: :class:`DocumentAuthorizationState <DocumentAuthorizationState>`.
+        self.authorization = json.get('authorization')
+
     def __repr__(self):
         return '{}(document_id={}, document_type={}, group_id={}, ' \
-            'your_number={}, current_state={}, security_code={}, receipt={})' \
+            'your_number={}, current_state={}, security_code={}, receipt={}, ' \
+            'authorization={})' \
             .format(self.__class__.__name__, self.document_id,
             self.document_type, self.group_id, self.your_number,
-            str(self.current_state), self.security_code, self.receipt)
+            str(self.current_state), self.security_code, self.receipt,
+            self.authorization)
 
     def update(self,
                document_type=None,
@@ -59,9 +67,10 @@ class Document:
         inserção de novos documentos na ordem correta.
 
         :param document_type: Código do tipo do documento.
-        :type document_type: int, optional
+        :type document_type: :class:`DocumentType <DocumentType>` ou
+            :class:`ExternalDocumentType <ExternalDocumentType>`, optional
 
-        :param document_data: Metadados do documento (string JSON).
+        :param document_data: Dados do documento (string JSON).
         :type document_data: str, optional
 
         :param document_file: Arquivo(s) do documento, onde um arquivo é uma
@@ -312,6 +321,35 @@ class Document:
                                                  self.document_id,
                                                  step), ))['message'])
 
+    def set_authorization(self, desired_auth_status, description):
+        '''
+        Atualiza o estado de autorização de um documento para permitir ou
+        proibir a assinatura e registro de um documento após a revisão manual
+        do arquivo gerado pelo Conector.
+
+        Atenção: documentos com a revisão manual desativada terão seu estado de
+        autorização atualizado para authorized automaticamente pelo Conector.
+
+        :param desired_auth_status: Estado de autorização desejado.
+        :type desired_auth_status: :class:`DocumentAuthorizationState <DocumentAuthorizationState>`
+
+        :param description: Descrição textual para o novo estado de autorização.
+        :type description: str
+
+        :return: ``True`` em caso de sucesso.
+        :rtype: bool
+        '''
+        parse_or_raise(
+            self._client.session.patch(
+                '{}/documents/{}/authorization'.format(self._client.base_url,
+                                                       self.document_id),
+                json={
+                    "documentAuthorization": desired_auth_status,
+                    "authorizationDescription": description
+                }))
+
+        return True
+
 
 class DocumentAuthenticityResult:
     '''
@@ -416,6 +454,9 @@ class DocumentSignature:
         #: Nome do assinante.
         self.signer = json.get('signer')
 
+        #: Identificador do assinante.
+        self.signer_id = json.get('signerId')
+
         #: Tag da assinatura.
         self.tag = json.get('tag')
 
@@ -437,11 +478,11 @@ class DocumentSignature:
             json.get('substituteSigner') else None
 
     def __repr__(self):
-        return '{}(signer={}, tag={}, state={}, archiving_signature={}, ' \
+        return '{}(signer={}, signer_id={}, tag={}, state={}, archiving_signature={}, ' \
             'substitute_signer={}, substitute_signature_state={})'.format(
-                self.__class__.__name__, self.signer, self.tag, str(self.state),
-                str(self.archiving_signature), self.substitute_signer,
-                str(self.substitute_signature_state))
+                self.__class__.__name__, self.signer, self.signer_id, self.tag,
+                str(self.state), str(self.archiving_signature),
+                self.substitute_signer, str(self.substitute_signature_state))
 
 
 class DocumentSignatureState:
@@ -569,6 +610,15 @@ class DocumentType:
     VISUAL_REP_DEGREE = 5
 
 
+class ExternalDocumentType:
+    '''Enumeração dos possíveis tipos de um :class:`Document <Document>`.'''
+    #: Diploma externo. Equivalente a ``external_degree``.
+    EXTERNAL_DEGREE = 6
+
+    #: Documentação acadêmica externa. Equivalente a ``external_academic_doc``.
+    EXTERNAL_ACADEMIC_DOC = 7
+
+
 class DocumentVersion:
     '''Enumeração das possíveis versões de um arquivo.'''
     # yapf: disable
@@ -576,3 +626,12 @@ class DocumentVersion:
     SIGNED = 'signedDocument' #: Versão assinada do documento.
     REGISTERED = 'registeredDocument' #: Versão registrada do documento.
     # yapf: enable
+
+
+class DocumentAuthorizationState:
+    '''Enumeração dos possíveis estados de autorização de um documento.'''
+    # yapf: disable
+    AUTHORIZED = 'authorized' #: Autorizado.
+    UNAUTHORIZED = 'unauthorized' #: Não-autorizado.
+    AWAITING = 'awaiting' #: Aguardando.
+    # yapf: enable
